@@ -29,11 +29,13 @@ newtype DynamicState = DynamicState { unDynamicState :: M.HashMap ConcreteTypeRe
 
 #if __GLASGOW_HASKELL__ >= 804
 instance Semigroup DynamicState where
-  (<>) = mappend
+  DynamicState a <> DynamicState b = DynamicState (a <> b)
 #endif
 
 instance Monoid DynamicState where
+#if !MIN_VERSION_base(4,11,0)
   mappend (DynamicState a) (DynamicState b) = DynamicState (mappend a b)
+#endif
   mempty = DynamicState mempty
 
 getDyn :: forall a. Typeable a => DynamicState -> Maybe a
